@@ -46,7 +46,7 @@ def lpad():
     get_fw_parser.add_argument('-i', '--fw_id', help='get FW with this fw_id', default=None, type=int)
     get_fw_parser.add_argument('-n', '--name', help='get FWs with this name', default=None)
     get_fw_parser.add_argument('-s', '--state', help='get FWs with this state ("ARCHIVED", "DEFUSED", "WAITING", "READY", "RESERVED", "FIZZLED", "RUNNING", "COMPLETED")', default=None)
-    get_fw_parser.add_argument('-q', '--query', help='get FWs matching this query (as pymongo string, enclose in single-quotes)', default=None)
+    get_fw_parser.add_argument('-q', '--query', help='get FWs matching this query (enclose pymongo-style dict in single-quotes, e.g. \'{"state":"COMPLETED"}\')', default=None)
     get_fw_parser.add_argument('-d', '--display_format', help='display_format ("all","more", "less","ids", "count")', default=None)
     get_fw_parser.add_argument('-m', '--max', help='limit results', default=0, type=int)
     get_fw_parser.add_argument('--sort', help='sort results ("created_on")', default=None)
@@ -57,7 +57,7 @@ def lpad():
     get_wf_parser.add_argument('-i', '--fw_id', help='get WF with this fw_id', default=None, type=int)
     get_wf_parser.add_argument('-n', '--name', help='get WFs with this name', default=None)
     get_wf_parser.add_argument('-s', '--state', help='get WFs with this state ("ARCHIVED", "DEFUSED", "READY", "RESERVED", "FIZZLED", "RUNNING", "COMPLETED")', default=None)
-    get_wf_parser.add_argument('-q', '--query', help='get WFs matching this query (as pymongo string, enclose in single-quotes)', default=None)
+    get_wf_parser.add_argument('-q', '--query', help='get WFs matching this query (enclose pymongo-style dict in single-quotes, e.g. \'{"state":"COMPLETED"}\')', default=None)
     get_wf_parser.add_argument('-d', '--display_format', help='display_format ("all","more", "less","ids", "count")', default=None)
     get_wf_parser.add_argument('-m', '--max', help='limit results', default=0, type=int)
     get_wf_parser.add_argument('--sort', help='sort results ("created_on", "updated_on")', default=None)
