@@ -48,7 +48,7 @@ def qlaunch():
     rapid_parser.add_argument('-m', '--maxjobs_queue', help='maximum jobs to keep in queue for this user', default=10,
                               type=int)
     rapid_parser.add_argument('-b', '--maxjobs_block', help='maximum jobs to put in a block', default=500, type=int)
-    rapid_parser.add_argument('--nlaunches', help='num_launches (int or "infinite")', default=0)
+    rapid_parser.add_argument('--nlaunches', help='num_launches (int or "infinite"; 0 indicates one round)', default=0)
     rapid_parser.add_argument('--sleep', help='sleep time between loops', default=None, type=int)
 
     args = parser.parse_args()
